==> jffnms_0.7.8.orig.tar.gz: jffnms-0.7.8/conf/config.php <==
<?
    error_reporting(7);
    $jffnms_logging_file = $_SERVER["PHP_SELF"];
    
    if (!isset($config_profile)) $config_profile="standard";

    $config_ini = array();
    $config_ini[$config_profile]=array();
    
    $config_file = "config.ini";
    $config_dirs = array("..",".","../conf","../../../conf","../../conf","/etc/jffnms");

    foreach ($config_dirs as $config_dir) 
	if (file_exists("$config_dir/$config_file")) {
	    $jffnms_config_ini_file = "$config_dir/$config_file";
	    break; //on first match
	}
        
    if (!$jffnms_config_ini_file) die ("Configuration file '$config_file', not found in ".join(", ",$config_dirs). ".");

    $config_ini=parse_ini_file($jffnms_config_ini_file,TRUE);

    while($config_key = key($config_ini[$config_profile])) {
	list ($config_value,$config_aux) = explode ("#",current($config_ini[$config_profile]));

	list ($config_type,$config_size,$config_comment) = explode(",",$config_aux);

	$config_value = trim($config_value);
	$config_comment = trim($config_comment);
	$config_type = trim($config_type);
	$config_size = trim($config_size);
	
	if (strpos($config_value,"%") > -1) {
	    $config_aux = substr($config_value,strpos($config_value,"%")+1,strrpos($config_value,"%")-1);
	    $config_value = str_replace("%$aux%",$jffnms_configuration[$config_aux]["value"],$config_value);
	}
	
	if (($config_key=="jffnms_rel_path") && ($config_value=="/.")) $config_value = ""; //special case for relative path

	$$config_key = $config_value;

	$jffnms_configuration[$config_key]=array("value"=>$config_value,"comment"=>$config_comment,"type"=>$config_type,"size"=>$config_size);
	next($config_ini[$config_profile]);
    }   

    unset($config_ini);
    unset($config_dirs);
    unset($config_dir);
    unset($config_key);
    unset($config_value);
    unset($config_type);
    unset($config_size);
    unset($config_comment);
    unset($config_aux);

    if (strstr($_SERVER["SCRIPT_FILENAME"], "setup.php"))  //take care of the real path for the setup page. (Robert Bogdon)
	$jffnms_real_path = str_replace("/conf", "", str_replace("\conf", "", dirname(__FILE__))); 
        
    if (!is_array($_SERVER["argv"])) $_SERVER["argv"]=$argv; // PHP 4.0.6 FIX

    if (!isset($jffnms_functions_include)) $jffnms_functions_include = "gui";

    if ($jffnms_functions_include!="none") {
	
	$jffnms_includes = array( "api","api.network" ); //add basic APIs an Network Communication

	if ($jffnms_access_method=="local") //add local clases
	    $jffnms_includes = array_merge( $jffnms_includes, array(
		"api.db","api.classes","api.events","api.rrdtool","api.user","api.profile",
		"api.interface","api.maps","api.hosts","api.zones","api.triggers","api.satellites",
		"api.tools", "api.nad"
	    ));

	if ($jffnms_functions_include!="engine") { //gui
	    $jffnms_includes[]="gui";
	    $jffnms_includes[]="gui.controls";
	
	    error_reporting(7);
	}
	
	require_once("$jffnms_real_path/conf/functions.php");
	set_time_limit(15*60);

	if ($jffnms_functions_include!="engine") { //gui

	    if ($jffnms_include_load_ok) {
		set_time_limit(420);
		
		if (!isset($jffnms_init_classes)) $jffnms_init_classes = 0;

		//init objects
		if ($jffnms_access_method=="satellite") {
		    $aux = new jffnms_access_api($jffnms_init_classes); //remote
		    $jffnms = $aux->get("jffnms");
		    unset ($aux);
		} else 
		    $jffnms = new jffnms($jffnms_init_classes); //local

	    } else { //if we couldnt find the functions file redirect to setup.php
		$jffnms_location = $_SERVER[REQUEST_URI];
	
		if (strpos($jffnms_location,"/admin/setup.php") === FALSE) { //we are not in the setup page
		    $jffnms_location = str_replace("/admin/setup.php","",$jffnms_location);
		    $jffnms_location .= "/admin/setup.php";

		    Header("Location: $jffnms_location");
		    die();    
		}
	    }
	}
    }

    unset($jffnms_location);
    unset($jffnms_include_load_ok);
    unset($jffnms_includes);
    unset($jffnms_functions_include); 
    unset($jffnms_init_classes); 

?>

==> jffnms_0.7.9.orig.tar.gz: jffnms-0.7.9/conf/config.php <==
<?
    error_reporting(7);
    $jffnms_logging_file = $_SERVER["PHP_SELF"];
    
    if (!isset($config_profile)) $config_profile="standard";

    $config_ini = array();
    $config_ini[$config_profile]=array();
    
    $config_file = "config.ini";
    $config_dirs = array("..",".","../conf","../../../conf","../../conf","/etc/jffnms");

    foreach ($config_dirs as $config_dir) 
	if (file_exists("$config_dir/$config_file")) {
	    $jffnms_config_ini_file = "$config_dir/$config_file";
	    break; //on first match
	}
        
    if (!$jffnms_config_ini_file) die ("Configuration file '$config_file', not found in ".join(", ",$config_dirs). ".");

    $config_ini=parse_ini_file($jffnms_config_ini_file,TRUE);

    if (count($config_ini)==2) { //FIX for PHP5 and our old config.ini
	$config_ini["standard"] += $config_ini["none"];
	unset ($config_ini["none"]);
    }
        
    while($config_key = key($config_ini[$config_profile])) {
	list ($config_value,$config_aux) = explode ("#",current($config_ini[$config_profile]));

	list ($config_type,$config_size,$config_comment) = explode(",",$config_aux);

	$config_value = trim($config_value);
	$config_comment = trim($config_comment);
	$config_type = trim($config_type);
	$config_size = trim($config_size);
	
	if (strpos($config_value,"%") > -1) {
	    $config_aux = substr($config_value,strpos($config_value,"%")+1,strrpos($config_value,"%")-1);
	    $config_value = str_replace("%$aux%",$jffnms_configuration[$config_aux]["value"],$config_value);
	}
	
	if (($config_key=="jffnms_rel_path") && ($config_value=="/.")) $config_value = ""; //special case for relative path

	$$config_key = $config_value;

	$jffnms_configuration[$config_key]=array("value"=>$config_value,"comment"=>$config_comment,"type"=>$config_type,"size"=>$config_size);
	next($config_ini[$config_profile]);
    }   

    unset($config_ini);
    unset($config_dirs);
    unset($config_dir);
    unset($config_key);
    unset($config_value);
    unset($config_type);
    unset($config_size);
    unset($config_comment);
    unset($config_aux);

    if (strstr($_SERVER["SCRIPT_FILENAME"], "setup.php"))  //take care of the real path for the setup page. (Robert Bogdon)
	$jffnms_real_path = str_replace("/conf", "", str_replace("\conf", "", dirname(__FILE__))); 
        
    if (!is_array($_SERVER["argv"])) $_SERVER["argv"]=$argv; // PHP 4.0.6 FIX

    if (!isset($jffnms_functions_include)) $jffnms_functions_include = "gui";

    if ($jffnms_functions_include!="none") {
	
	$jffnms_includes = array( "api","api.network" ); //add basic APIs an Network Communication

	if ($jffnms_access_method=="local") //add local clases
	    $jffnms_includes = array_merge( $jffnms_includes, array(
		"api.db","api.classes","api.events","api.rrdtool","api.user","api.profile",
		"api.interface","api.maps","api.hosts","api.zones","api.triggers","api.satellites",
		"api.tools", "api.nad"
	    ));

	if ($jffnms_functions_include!="engine") { //gui
	    $jffnms_includes[]="gui";
	    $jffnms_includes[]="gui.controls";
	
	    error_reporting(7);
	}
	
	require_once("$jffnms_real_path/conf/functions.php");
	set_time_limit(15*60);

	if ($jffnms_functions_include!="engine") { //gui

	    if ($jffnms_include_load_ok) {
		set_time_limit(420);
		
		if (!isset($jffnms_init_classes)) $jffnms_init_classes = 0;

		//init objects
		if ($jffnms_access_method=="satellite") {
		    $aux = new jffnms_access_api($jffnms_init_classes); //remote
		    $jffnms = $aux->get("jffnms");
		    unset ($aux);
		} else 
		    $jffnms = new jffnms($jffnms_init_classes); //local

	    } else { //if we couldnt find the functions file redirect to setup.php
		$jffnms_location = $_SERVER[REQUEST_URI];
	
		if (strpos($jffnms_location,"/admin/setup.php") === FALSE) { //we are not in the setup page
		    $jffnms_location = str_replace("/admin/setup.php","",$jffnms_location);
		    $jffnms_location .= "/admin/setup.php";

		    Header("Location: $jffnms_location");
		    die();    
		}
	    }
	}
    }

    unset($jffnms_location);
    unset($jffnms_include_load_ok);
    unset($jffnms_includes);
    unset($jffnms_functions_include); 
    unset($jffnms_init_classes); 

?>
